@@ -27,4 +27,4 @@ data = {"entry": [{'category': [{'term': 'weblog', 'label': 'Weblog'},
                    'updated': '2007-01-18T13:31:43Z'}],
         "title": "This is the title"}
 
-print template.process(data).prettify()
+print template.process(data, escape=False).prettify()
